==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-BR/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Mais Informações",

    "audit_help" => "Marcar esta caixa irá editar o registro de ativos para refletir esse novo local. Deixando-o desmarcado irá simplesmente anotar o local no log de auditoria.<br><br>Note que este ativo é verificado, não irá alterar a localização da pessoa, ativo ou local para onde for reservado.",

    'assets' => 'Ativos são itens que são controlados e rastreáveis pelo número de série ou por uma etiqueta de ativo (patrimônio). Eles tendem a ser de valor elevado onde a identificação de itens específicos é relevante.',

    'categories' => 'Categorias auxiliam na organização dos seus itens. Alguns exemplos de categorias podem ser: &quot;Desktops&quot;, &quot;Notebooks&quot;, &quot;Celulares&quot;, &quot;Tablets&quot;, e assim por diante, mas você pode usar as Categorias de melhor forma que você identificar.',

    'accessories' => 'Acessórios são qualquer coisa que você emitir para os usuários, mas que não tem um número de série (ou você não se importa com o seu rastreamento único). Por exemplo, mouse ou teclados de computador.',

    'companies'     => 'Empresas podem ser utilizadas como um campo para simples identificação, ou pode ser utilizada para limitar a visualização dos ativos, usuários, etc. Elas ficam disponíveis para uso, se estiver configurado nas opções de Administração.',

    'components'    => 'Componentes são itens que fazem parte de ativos, como por exemplo HDD, RAM, etc.',

    'consumables'   => 'Consumíveis é todo e qualquer item comprado que será usado ao longo do tempo, por exemplo, papel ou tinta de impressora.',

    'depreciations' => 'Você pode configurar depreciações para depreciar ativos baseados na depreciação linear.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-BR/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Mais Informações',

    'audit_help' => 'Marcar esta caixa irá editar o registro de ativos para refletir esse novo local. Deixando-o desmarcado irá simplesmente anotar o local no log de auditoria.<br><br>Note que este ativo é verificado, não irá alterar a localização da pessoa, ativo ou local para onde for reservado.',

    'assets' => 'Ativos são itens que são controlados e rastreáveis pelo número de série ou por uma etiqueta de ativo (patrimônio). Eles tendem a ser de valor elevado onde a identificação de itens específicos é relevante.',

    'categories' => 'Categorias auxiliam na organização dos seus itens. Alguns exemplos de categorias podem ser: &quot;Desktops&quot;, &quot;Notebooks&quot;, &quot;Celulares&quot;, &quot;Tablets&quot;, e assim por diante, mas você pode usar as Categorias de melhor forma que você identificar.',

    'accessories' => 'Acessórios são qualquer coisa que você emitir para os usuários, mas que não tem um número de série (ou você não se importa com o seu rastreamento único). Por exemplo, mouse ou teclados de computador.',

    'companies'     => 'Empresas podem ser utilizadas como um campo para simples identificação, ou pode ser utilizada para limitar a visualização dos ativos, usuários, etc. Elas ficam disponíveis para uso, se estiver configurado nas opções de Administração.',

    'components'    => 'Componentes são itens que fazem parte de ativos, como por exemplo HDD, RAM, etc.',

    'consumables'   => 'Consumíveis é todo e qualquer item comprado que será usado ao longo do tempo, por exemplo, papel ou tinta de impressora.',

    'depreciations' => 'Você pode configurar depreciações para depreciar ativos baseados na depreciação linear.',

];
